@@ -1,4 +1,6 @@
-/* 
+/*
+ * $Id: pi-debug.h,v 1.9 2006/10/17 13:24:06 desrod Exp $
+ *
  * pi-debug.h: Debugging utilities
  *
  * This library is free software; you can redistribute it and/or modify it
@@ -13,7 +15,7 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. *
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef _PILOT_DEBUG_H_
@@ -56,17 +58,24 @@ extern void pi_debug_set_level  PI_ARGS((int level));
 
 extern void pi_debug_set_file PI_ARGS((const char *path));
 
-extern void pi_log PI_ARGS((int type, int level, char *format, ...));
+extern void pi_log PI_ARGS((int type, int level, PI_CONST char *format, ...));
+
+extern void pi_dumpline
+    PI_ARGS((PI_CONST char *buf, size_t len, unsigned int addr));
+
+extern void pi_dumpdata
+    PI_ARGS((PI_CONST char *buf, size_t len));
 
 #ifdef PI_DEBUG
 #define ASSERT(expr)                                            \
      do {                                                       \
-       if (!(expr))						\
+       if (!(expr)) {						\
          pi_log (PI_DBG_ALL, PI_DBG_LVL_NONE,                   \
 	         "file %s: line %d: assertion failed: (%s)",	\
 	         __FILE__,                                      \
 	         __LINE__,                                      \
 	         #expr);                                        \
+	} 							\
      } while (0);
 
 #define CHECK(type, level, expr)                                \
@@ -90,6 +99,3 @@ extern void pi_log PI_ARGS((int type, int level, char *format, ...));
 }
 #endif
 #endif
-
-
-
