@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <stdlib.h>
@@ -298,7 +298,7 @@ store_record_on_pilot(SyncHandler * sh, int dbhandle,
 {
 	int 	result = 0;
 	PilotRecord precord;
-	recordid_t id;
+	recordid_t id_;
 
 	memset(&precord, 0, sizeof(PilotRecord));
 
@@ -306,11 +306,11 @@ store_record_on_pilot(SyncHandler * sh, int dbhandle,
 	if (result != 0)
 		return result;
 
-	PilotCheck(dlp_WriteRecord(sh->sd, dbhandle, 0,
+	PilotCheck(dlp_WriteRecord(sh->sd, dbhandle, precord.flags & dlpRecAttrSecret,
 				   precord.recID, precord.catID,
-				   precord.buffer, precord.len, &id));
+				   precord.buffer, precord.len, &id_));
 
-	DesktopCheck(sh->SetPilotID(sh, drecord, id));
+	DesktopCheck(sh->SetPilotID(sh, drecord, id_));
 
 	return result;
 }
@@ -579,6 +579,7 @@ int sync_CopyFromPilot(SyncHandler * sh)
 		i,	
 		slow 	= 0,
 		result 	= 0;
+	pi_buffer_t *recbuf;
 
 	DesktopRecord *drecord = NULL;
 	PilotRecord *precord = sync_NewPilotRecord(DLP_BUF_SIZE);
@@ -598,21 +599,28 @@ int sync_CopyFromPilot(SyncHandler * sh)
 	}
 
 	i = 0;
-	while (dlp_ReadRecordByIndex
-	       (sh->sd, dbhandle, i, precord->buffer, &precord->recID,
-		&precord->len, &precord->flags, &precord->catID) > 0) {
+	recbuf = pi_buffer_new(DLP_BUF_SIZE);
+	while (dlp_ReadRecordByIndex(sh->sd, dbhandle, i, recbuf, &precord->recID,
+		   &precord->flags, &precord->catID) > 0) {
+		precord->len = recbuf->used;
+		if (precord->len > DLP_BUF_SIZE)
+			precord->len = DLP_BUF_SIZE;
+		memcpy(precord->buffer, recbuf->data, precord->len);
 		result = sh->AddRecord(sh, precord);
-		if (result < 0)
+		if (result < 0) {
+			pi_buffer_free(recbuf);
 			goto cleanup;
+		}
 
 		i++;
 	}
+	pi_buffer_free (recbuf);
 
 	result = sh->Post(sh, dbhandle);
 
-      cleanup:
+cleanup:
 	close_db(sh, dbhandle);
-
+	sync_FreePilotRecord (precord);
 	return result;
 }
 
@@ -670,13 +678,17 @@ sync_MergeFromPilot_fast(SyncHandler * sh, int dbhandle,
 	PilotRecord *precord 	= sync_NewPilotRecord(DLP_BUF_SIZE);
 	DesktopRecord *drecord 	= NULL;
 	RecordQueue rq 		= { 0, NULL };
-
-	while (dlp_ReadNextModifiedRec(sh->sd, dbhandle, precord->buffer,
+	pi_buffer_t *recbuf = pi_buffer_new(DLP_BUF_SIZE);
+	
+	while (dlp_ReadNextModifiedRec(sh->sd, dbhandle, recbuf,
 				       &precord->recID, NULL,
-				       &precord->len, &precord->flags,
+				       &precord->flags,
 				       &precord->catID) >= 0) {
 		int count = rq.count;
-
+		precord->len = recbuf->used;
+		if (precord->len > DLP_BUF_SIZE)
+			precord->len = DLP_BUF_SIZE;
+		memcpy(precord->buffer, recbuf->data, precord->len);
 		ErrorCheck(sh->Match(sh, precord, &drecord));
 		ErrorCheck(sync_record
 			   (sh, dbhandle, drecord, precord, &rq, rec_mod));
@@ -684,6 +696,7 @@ sync_MergeFromPilot_fast(SyncHandler * sh, int dbhandle,
 		if (drecord && rq.count == count)
 			ErrorCheck(sh->FreeMatch(sh, drecord));
 	}
+	pi_buffer_free(recbuf);
 	sync_FreePilotRecord(precord);
 
 	result = sync_MergeFromPilot_process(sh, dbhandle, &rq, rec_mod);
@@ -710,17 +723,24 @@ sync_MergeFromPilot_slow(SyncHandler * sh, int dbhandle,
 		parch, 
 		psecret,
 		result = 0;
+	pi_buffer_t *recbuf;
 
 	PilotRecord *precord 	= sync_NewPilotRecord(DLP_BUF_SIZE);
 	DesktopRecord *drecord 	= NULL;
 	RecordQueue rq 		= { 0, NULL };
 
 	i = 0;
+	recbuf = pi_buffer_new(DLP_BUF_SIZE);
 	while (dlp_ReadRecordByIndex
-	       (sh->sd, dbhandle, i, precord->buffer, &precord->recID,
-		&precord->len, &precord->flags, &precord->catID) > 0) {
+	       (sh->sd, dbhandle, i, recbuf, &precord->recID,
+			&precord->flags, &precord->catID) > 0) {
 		int 	count = rq.count;
 
+		precord->len = recbuf->used;
+		if (precord->len > DLP_BUF_SIZE)
+			precord->len = DLP_BUF_SIZE;
+		memcpy(precord->buffer, recbuf->data, precord->len);
+		
 		ErrorCheck(sh->Match(sh, precord, &drecord));
 
 		/* Since this is a slow sync, we must calculate the flags */
@@ -753,6 +773,8 @@ sync_MergeFromPilot_slow(SyncHandler * sh, int dbhandle,
 
 		i++;
 	}
+	pi_buffer_free(recbuf);
+
 	sync_FreePilotRecord(precord);
 
 	result = sync_MergeFromPilot_process(sh, dbhandle, &rq, rec_mod);
@@ -823,6 +845,7 @@ sync_MergeToPilot_fast(SyncHandler * sh, int dbhandle,
 	PilotRecord *precord 	= NULL;
 	DesktopRecord *drecord 	= NULL;
 	RecordQueue rq 		= { 0, NULL };
+	pi_buffer_t *recbuf = pi_buffer_new(DLP_BUF_SIZE);
 
 	while (sh->ForEachModified(sh, &drecord) == 0 && drecord) {
 		if (drecord->recID != 0) {
@@ -830,10 +853,14 @@ sync_MergeToPilot_fast(SyncHandler * sh, int dbhandle,
 			precord->recID = drecord->recID;
 			PilotCheck(dlp_ReadRecordById(sh->sd, dbhandle,
 						      precord->recID,
-						      precord->buffer,
-						      NULL, &precord->len,
+						      recbuf,
+						      NULL,
 						      &precord->flags,
 						      &precord->catID));
+			precord->len = recbuf->used;
+			if (precord->len > DLP_BUF_SIZE)
+				precord->len = DLP_BUF_SIZE;
+			memcpy(precord->buffer, recbuf->data, precord->len);
 		}
 
 		ErrorCheck(sync_record
@@ -843,6 +870,7 @@ sync_MergeToPilot_fast(SyncHandler * sh, int dbhandle,
 			sync_FreePilotRecord (precord);
 		precord = NULL;
 	}
+	pi_buffer_free(recbuf);
 
 	result = sync_MergeFromPilot_process(sh, dbhandle, &rq, rec_mod);
 
@@ -870,7 +898,7 @@ sync_MergeToPilot_slow(SyncHandler * sh, int dbhandle,
 	PilotRecord *precord 	= NULL;
 	DesktopRecord *drecord 	= NULL;
 	RecordQueue rq 		= { 0, NULL };
-
+	pi_buffer_t *recbuf = pi_buffer_new(DLP_BUF_SIZE);
 
 	while (sh->ForEach(sh, &drecord) == 0 && drecord) {
 		if (drecord->recID != 0) {
@@ -878,10 +906,14 @@ sync_MergeToPilot_slow(SyncHandler * sh, int dbhandle,
 			precord->recID = drecord->recID;
 			PilotCheck(dlp_ReadRecordById(sh->sd, dbhandle,
 						      precord->recID,
-						      precord->buffer,
-						      NULL, &precord->len,
+						      recbuf,
+						      NULL,
 						      &precord->flags,
 						      &precord->catID));
+			precord->len = recbuf->used;
+			if (precord->len > DLP_BUF_SIZE)
+				precord->len = DLP_BUF_SIZE;
+			memcpy(precord->buffer, recbuf->data, precord->len);
 		}
 
 		/* Since this is a slow sync, we must calculate the flags */
@@ -913,6 +945,7 @@ sync_MergeToPilot_slow(SyncHandler * sh, int dbhandle,
 			sync_FreePilotRecord (precord);
 		precord = NULL;
 	}
+	pi_buffer_free(recbuf);
 
 	result = sync_MergeFromPilot_process(sh, dbhandle, &rq, rec_mod);
 
